@@ -5,7 +5,7 @@ import codecs
 
 # return stdout, stderr
 # raise exception if failed to execute
-def run(cmd, timeout=None):
-    proc = Popen(shlex.split(cmd), stdout=PIPE, stderr=PIPE)
-    stdout_b, stderr_b = proc.communicate(timeout=timeout)
+def run(cmd, timeout_sec=None, execute_dir=None):
+    proc = Popen(shlex.split(cmd), stdout=PIPE, stderr=PIPE, cwd=execute_dir)
+    stdout_b, stderr_b = proc.communicate(timeout=timeout_sec)
     return codecs.decode(stdout_b).strip(), codecs.decode(stderr_b).strip()
